==> blesta-5.10.2.zip: blesta/plugins/order/language/tr_tr/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Kurtarma E-postası (İsteğe Bağlı)';
$lang['Signup.!error.email.blacklist'] = 'Siparişiniz şu anda işleme alınamamaktadır.';
$lang['Signup.index.signup_btn'] = 'Hesap oluştur';
$lang['Signup.index.continue_btn'] = 'Ödeme işlemine devam edin';
$lang['Signup.index.login_btn'] = 'Giriş yap';
$lang['Signup.index.field_receive_email_marketing'] = 'Yeni ürünler, hizmetler ve teklifler hakkında e-posta almak istiyorum.';
$lang['Signup.index.field_confirmpassword'] = 'Şifreyi Onayla';
$lang['Signup.index.field_newpassword'] = 'Şifre';
$lang['Signup.index.field_password'] = 'Şifre';
$lang['Signup.index.field_username'] = 'Kullanıcı Adı';
$lang['Signup.index.field_action_signup'] = 'Bir hesap oluşturun';
$lang['Signup.index.field_action_login'] = 'Giriş Yap';
$lang['Signup.index.field_action_continue'] = '1$s %2$s olarak devam edin';
$lang['Signup.index.field_username_type_username'] = 'Bir kullanıcı adı belirtin';
$lang['Signup.index.field_username_type_email'] = 'Kullanıcı adı olarak e-posta kullanın';
$lang['Signup.index.field_email'] = 'E-posta';
$lang['Signup.index.field_fax'] = 'Faks';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Başlık';
$lang['Signup.index.field_country'] = 'Ülke';
$lang['Signup.index.field_zip'] = 'Posta Kodu';
$lang['Signup.index.field_state'] = 'Eyalet/İl';
$lang['Signup.index.field_city'] = 'Şehir';
$lang['Signup.index.field_address2'] = 'Adres 2';
$lang['Signup.index.field_address1'] = 'Adres 1';
$lang['Signup.index.field_company'] = 'Şirket/Org.';
$lang['Signup.index.field_lastname'] = 'Soyadı';
$lang['Signup.index.field_firstname'] = 'İlk İsim';
$lang['Signup.index.field_taxid'] = 'Vergi Kimliği/VATIN';
$lang['Signup.!notice.email_verification'] = 'E-posta adresinizi doğrulamak için bir mesaj gönderildi. Lütfen en kısa sürede doğrulama işlemini tamamlayın.';
$lang['Signup.!notice.force_email_usernames'] = 'Kullanıcı adınız e-posta adresinizle aynı olacaktır.';
$lang['Signup.!error.not_client_owner'] = 'Devam edebilmek için müşteri sahibi olarak oturum açmış olmanız gerekmektedir.';
$lang['Signup.!error.captcha.invalid'] = 'Girilen captcha geçersiz. Lütfen tekrar deneyin.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/tr_tr/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Kurtarma E-postası (İsteğe Bağlı)';
$lang['Signup.!error.email.blacklist'] = 'Siparişiniz şu anda işleme alınamamaktadır.';
$lang['Signup.index.signup_btn'] = 'Hesap oluştur';
$lang['Signup.index.continue_btn'] = 'Ödeme işlemine devam edin';
$lang['Signup.index.login_btn'] = 'Giriş yap';
$lang['Signup.index.field_receive_email_marketing'] = 'Yeni ürünler, hizmetler ve teklifler hakkında e-posta almak istiyorum.';
$lang['Signup.index.field_confirmpassword'] = 'Şifreyi Onayla';
$lang['Signup.index.field_newpassword'] = 'Şifre';
$lang['Signup.index.field_password'] = 'Şifre';
$lang['Signup.index.field_username'] = 'Kullanıcı Adı';
$lang['Signup.index.field_action_signup'] = 'Bir hesap oluşturun';
$lang['Signup.index.field_action_login'] = 'Giriş Yap';
$lang['Signup.index.field_username_type_username'] = 'Bir kullanıcı adı belirtin';
$lang['Signup.index.field_username_type_email'] = 'Kullanıcı adı olarak e-posta kullanın';
$lang['Signup.index.field_email'] = 'E-posta';
$lang['Signup.index.field_fax'] = 'Faks';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Başlık';
$lang['Signup.index.field_country'] = 'Ülke';
$lang['Signup.index.field_zip'] = 'Posta Kodu';
$lang['Signup.index.field_state'] = 'Eyalet/İl';
$lang['Signup.index.field_city'] = 'Şehir';
$lang['Signup.index.field_address2'] = 'Adres 2';
$lang['Signup.index.field_address1'] = 'Adres 1';
$lang['Signup.index.field_company'] = 'Şirket/Org.';
$lang['Signup.index.field_lastname'] = 'Soyadı';
$lang['Signup.index.field_firstname'] = 'İlk İsim';
$lang['Signup.index.field_taxid'] = 'Vergi Kimliği/VATIN';
$lang['Signup.!notice.email_verification'] = 'E-posta adresinizi doğrulamak için bir mesaj gönderildi. Lütfen en kısa sürede doğrulama işlemini tamamlayın.';
$lang['Signup.!notice.force_email_usernames'] = 'Kullanıcı adınız e-posta adresinizle aynı olacaktır.';
$lang['Signup.!error.not_client_owner'] = 'Devam edebilmek için müşteri sahibi olarak oturum açmış olmanız gerekmektedir.';
$lang['Signup.!error.captcha.invalid'] = 'Girilen captcha geçersiz. Lütfen tekrar deneyin.';
$lang['Signup.index.field_action_continue'] = 'Continue as %1$s %2$s';
$lang['Signup.otp.field_submit'] = 'Giriş Yap';
$lang['Signup.otp.field_otp'] = 'Tek Kullanımlık Şifre';
$lang['Signup.otp.login_heading'] = 'Giriş Yap';
$lang['Signup.otp.description'] = 'Lütfen Tek Kullanımlık Şifrenizi girin.';
$lang['Signup.otp.page_title'] = 'Giriş Yap';
$lang['Signup.index.field_agree_tos'] = '<a href="%1$s" target="_blank">Hüküm ve Koşulları</a> okudum ve kabul ediyorum';
$lang['Signup.!error.invalid_agree_tos'] = 'Hüküm ve koşulları kabul ettiğinizi onaylamanız gerekmektedir.';
